@@ -450,10 +450,7 @@ def add_organization_account_template_variables(parser):
         default=False,
     )
     parser.add_argument(
-        "--organization-region-variables",
-        help="Add AWSRegions as Jinja variables",
-        action="store_true",
-        default=False,
+        "--organization-region-variables", help="Add AWSRegions as Jinja variables", action="store_true", default=False
     )
     parser.add_argument(
         "--organization-account-variables",
@@ -660,7 +657,7 @@ def deploy(args, client):
     elif status == "FAILED" and "The submitted information didn't contain changes." in reason:
         logger.info("ChangeSet did not contain any changes")
     else:
-        logger.info("ChangeSet is not executable. Status: {}, Reason: ".format(status, reason))
+        logger.info("ChangeSet is not executable. Status: {}, Reason: {}".format(status, reason))
         sys.exit(1)
 
 
