@@ -1,7 +1,7 @@
-import glob
 import json
 import os
 import sys
+import re
 
 import logging
 import yaml
@@ -42,6 +42,11 @@ def code_escape(source):
     return source.replace("\n", "\\n").replace('"', '\\"')
 
 
+def code_array(source):
+    lines = source.split("\\n")
+    return "[" + ",".join(['"%s"' % line for line in lines]) + "]"
+
+
 def mandatory(a):
     from jinja2.runtime import Undefined
 
@@ -70,7 +75,13 @@ class Loader(object):
         self.filename = filename
         self.env = Environment(loader=FileSystemLoader("./", followlinks=True))
         self.env.filters.update(
-            {"code_escape": code_escape, "mandatory": mandatory, "resource": resource, "novalue": novalue}
+            {
+                "code_escape": code_escape,
+                "code_array": code_array,
+                "mandatory": mandatory,
+                "resource": resource,
+                "novalue": novalue,
+            }
         )
         self.variables = variables
         self.main_account_parameter = main_account_parameter
@@ -137,7 +148,15 @@ class Loader(object):
             logger.info("File {} is empty".format(file))
 
     def load_module(self, module_path, element_key, element_value):
-        module_path = self.path + "/" + "/".join(module_path.lower().split("::"))
+        path_elements = module_path.split("::")
+        dir_pattern = re.compile(fnmatch.translate(path_elements.pop(0)), re.IGNORECASE)
+        matched_dirs = [dir for dir in os.listdir(self.path) if dir_pattern.match(dir)]
+        matched_dir = module_path
+        if matched_dirs:
+            matched_dir = matched_dirs[0]
+
+        module_path = self.path + "/" + "/".join([matched_dir] + path_elements)
+
         file_name = "*"
 
         if not os.path.isdir(module_path):
@@ -164,7 +183,8 @@ class Loader(object):
         files = []
 
         for file_type in FILE_TYPES:
-            files.extend(glob.glob("{}/{}.template.{}".format(self.path, self.filename, file_type)))
+            pattern = re.compile(fnmatch.translate("{}.template.{}".format(self.filename, file_type)), re.IGNORECASE)
+            files.extend([filename for filename in os.listdir(self.path) if pattern.match(filename)])
 
         if not files:
             logger.info("Could not find any template files in {}".format(self.path))
